@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package MooseX::AttributeIndexes;
-our $VERSION = '0.01000613';
+our $VERSION = '0.01001007';
 
 
 # ABSTRACT: Advertise metadata about your Model-Representing Classes to Any Database tool.
@@ -47,7 +47,7 @@ MooseX::AttributeIndexes - Advertise metadata about your Model-Representing Clas
 
 =head1 VERSION
 
-version 0.01000613
+version 0.01001007
 
 =head1 SYNOPSIS
 
@@ -103,6 +103,23 @@ version 0.01000613
 
 
 
+=head2 CODERef
+
+Since 0.01001007, the following notation is also supported:
+
+  has 'name' => (
+    ...
+    indexed => sub {
+      my ( $attribute_meta, $object, $value ) = @_;
+      return "$_" ; # $_ == $value
+    }
+  );
+
+Noting of course, $value is populated by the meta-accessor.
+
+This is a simple way to add exceptions for weird cases for things you want to index that
+don't behave like they should.
+
 =head3 SEE ALSO
 
 L<Search::GIN::Extract::AttributeIndexes>
